==> hexo-theme-solitude-2.0.10.tgz: package/README_zh-Hans.md <==
[English](README.md)丨简体中文丨[繁体中文](README_zh-Hant.md)

<div align="center">

   <h1>Solitude</h1>

   一款优雅的 Hexo 主题，支持懒加载、PWA、Latex 以及多种评论系统。

   主题设计由 [@张洪Heo](https://github.com/zhheo) 全权授权

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?style=for-the-badge)
![license](https://img.shields.io/github/license/everfu/hexo-theme-solitude?color=FF5531&style=for-the-badge)
[![Stars](https://img.shields.io/github/stars/everfu/hexo-theme-solitude?style=for-the-badge)](https://github.com/everfu/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white&style=for-the-badge)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white&style=for-the-badge)
![node version](https://img.shields.io/badge/node-14.0.0+-white?logo=node.js&logoColor=white&style=for-the-badge)

![page view](https://komarev.com/ghpvc/?username=hexo-theme-solitude&abbreviated=true&base=12345&style=for-the-badge)
[![discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains&style=for-the-badge)

[文档](https://solitude.js.org/)丨[预览](https://solitude.js.org/preview/zh/)

</div>

<div style="width: 80%; margin: 0 auto">

![Screenshot](.github/screenshot.avif)

</div>

## 特性

- 页面懒加载（Pjax）、图片懒加载（LazyLoad）、离线应用（PWA）
- 评论(Twikoo、Waline、Valine、Artalk、Giscus)，支持双评论
- 昼夜切换(ColorMode)
- 灯箱(medium-zoom、fancybox)
- 数学公式(Latex)
- 特色页面：即刻短文、我的装备、在线工具、音乐馆、友链鱼塘、相册页、豆瓣页、弹幕留言页
- 文章功能：AI 摘要、代码高亮

## Todo

- [x] 首页顶部新样式
- [x] 首页文章列表三列显示
- [x] btns 外挂标签

> 如有问题请提 [issue](https://github.com/everfu/hexo-theme-solitude/issues)

## 应用

1. 使用 NPM 包进行安装
      ```bash
      npm i hexo-theme-solitude
      ```
2. 应用主题
      ```yaml
      theme: solitude
      ```

前往 [文档](https://solitude.js.org/) 获取更多信息。

## 赞助者

<div align="center">

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W1YSMOK)

</div>

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg' alt="赞助者"/>
  </a>
</p>

## 社区

[![Discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
[![QQ 群](https://img.shields.io/badge/QQ%20群-948375336-FFD700?logo=Tencent-QQ&logoColor=white&style=for-the-badge)](https://qm.qq.com/q/mxfomMvJPG)

## 版权

[MIT](./LICENSE) License &copy; 2023-至今 [EverFu](https://github.com/efuo)

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fvalor-x%2Fhexo-theme-solitude.svg?type=large)](https://app.fossa.com/projects/git%2Bgithub.com%2Fvalor-x%2Fhexo-theme-solitude?ref=badge_large)

==> hexo-theme-solitude-2.0.11.tgz: package/README_zh-Hans.md <==
[English](README.md)丨简体中文丨[繁体中文](README_zh-Hant.md)

<div align="center">

   <h1>Solitude</h1>

   一款优雅的 Hexo 主题，支持懒加载、PWA、Latex 以及多种评论系统。

   主题设计由 [@张洪Heo](https://github.com/zhheo) 全权授权

![npm package](https://img.shields.io/npm/v/hexo-theme-solitude?style=for-the-badge)
![license](https://img.shields.io/github/license/everfu/hexo-theme-solitude?color=FF5531&style=for-the-badge)
[![Stars](https://img.shields.io/github/stars/everfu/hexo-theme-solitude?style=for-the-badge)](https://github.com/everfu/hexo-theme-solitude/stargazers)
[![NPM all downloads](https://img.shields.io/npm/dy/hexo-theme-solitude?color=white&style=for-the-badge)](https://www.npmjs.com/package/hexo-theme-solitude)

![hexo version](https://img.shields.io/badge/hexo-7.0.0+-blue?logo=hexo&logoColor=white&style=for-the-badge)
![node version](https://img.shields.io/badge/node-14.0.0+-white?logo=node.js&logoColor=white&style=for-the-badge)

![page view](https://komarev.com/ghpvc/?username=hexo-theme-solitude&abbreviated=true&base=12345&style=for-the-badge)
[![discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
![JetBrains](https://img.shields.io/badge/jetbrains-support-black?logo=jetbrains&style=for-the-badge)

[文档](https://solitude.js.org/)丨[预览](https://solitude.js.org/preview/zh/)丨[作者](https://blog.everfu.cn/)

</div>

<div style="width: 80%; margin: 0 auto">

![Screenshot](.github/screenshot.avif)

</div>

## 特性

- 页面懒加载（Pjax）、图片懒加载（LazyLoad）、离线应用（PWA）
- 评论(Twikoo、Waline、Valine、Artalk、Giscus)，支持双评论
- 昼夜切换(ColorMode)
- 灯箱(medium-zoom、fancybox)
- 数学公式(Latex)
- 特色页面：即刻短文、我的装备、在线工具、音乐馆、友链鱼塘、相册页、豆瓣页、弹幕留言页
- 文章功能：AI 摘要、代码高亮

## Todo

- [x] 首页顶部新样式
- [x] 首页文章列表三列显示
- [x] btns 外挂标签

> 如有问题请提 [issue](https://github.com/everfu/hexo-theme-solitude/issues)

## 应用

1. 使用 NPM 包进行安装
      ```bash
      npm i hexo-theme-solitude
      ```
2. 应用主题
      ```yaml
      theme: solitude
      ```

前往 [文档](https://solitude.js.org/) 获取更多信息。

## 赞助者

<div align="center">

[![ko-fi](https://ko-fi.com/img/githubbutton_sm.svg)](https://ko-fi.com/W7W1YSMOK)

</div>

<p align="center">
  <a href="https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg">
    <img src='https://cdn.jsdelivr.net/gh/efuo/static/sponsors.svg' alt="赞助者"/>
  </a>
</p>

## 社区

[![Discord](https://img.shields.io/discord/1266610921942548553?style=for-the-badge&logo=discord&label=discord&logoColor=white)](https://discord.gg/HZXAnK4Sut)
[![QQ 群](https://img.shields.io/badge/QQ%20群-948375336-FFD700?logo=Tencent-QQ&logoColor=white&style=for-the-badge)](https://qm.qq.com/q/mxfomMvJPG)

## 版权

[MIT](./LICENSE) License &copy; 2023-至今 [EverFu](https://github.com/efuo)

[![FOSSA Status](https://app.fossa.com/api/projects/git%2Bgithub.com%2Fvalor-x%2Fhexo-theme-solitude.svg?type=large)](https://app.fossa.com/projects/git%2Bgithub.com%2Fvalor-x%2Fhexo-theme-solitude?ref=badge_large)
